@@ -37,4 +37,29 @@ pipe_to:
 # The above 2 plans are equivalent. Choose your weapon, delete the other and adapt
 # (No, don't try to use this plan without adapting it..!)|);
 
+
+=head1 NAME
+
+TaskPipe::Template_Plan_Stub - template for the default plan
+
+=head1 DESCRIPTION
+
+This is the template responsible for creating the default plan (ie just a plan stub)
+
+=head1 AUTHOR
+
+Tom Gracey <tomgracey@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (c) Tom Gracey 2018
+
+TaskPipe is free software, licensed under
+
+    The GNU Public License Version 3
+
+=cut
+
+
+
 1;
